mod client;
mod delete;
mod get;
mod head;
mod http_;
mod options;
mod patch;
mod pool;
mod post;
mod put;
mod resolver;
mod timeout_extractor_reader;
mod unix_socket;

pub use delete::HttpDelete;
pub use get::HttpGet;
pub use head::HttpHead;
pub use http_::Http;
pub use options::HttpOptions;
pub use patch::HttpPatch;
pub use pool::HttpPool;
pub use post::HttpPost;
pub use put::HttpPut;
